@@ -124,6 +124,10 @@ class BaseImage(object):
             self._surface = pygame.image.load(image_path)  # type: pygame.Surface
             self._original_surface = self._surface.copy()
 
+        # Other internals
+        self._last_transform = (0, 0, None)  # Improves drawing
+        self.smooth_scaling = True  # Uses smooth scaling by default in draw() method
+
     def get_path(self):
         """
         Return the image path.
@@ -176,6 +180,26 @@ class BaseImage(object):
         assert_vector2(drawing_offset)
         self._drawing_offset = (drawing_offset[0], drawing_offset[1])
 
+    def __copy__(self):
+        """
+        Copy method.
+
+        :return: New instance of the object
+        :rtype: BaseImage
+        """
+        return self.copy()
+
+    def __deepcopy__(self, memodict):
+        """
+        Deepcopy method.
+
+        :param memodict: Memo dict
+        :type memodict: dict
+        :return: New instance of the object
+        :rtype: BaseImage
+        """
+        return self.copy()
+
     def copy(self):
         """
         Return a copy of the image.
@@ -186,10 +210,12 @@ class BaseImage(object):
         image = BaseImage(
             image_path=self._filepath,
             drawing_mode=self._drawing_mode,
-            drawing_offset=self._drawing_offset
+            drawing_offset=self._drawing_offset,
+            load_from_file=False
         )
         image._surface = self._surface.copy()
         image._original_surface = self._surface.copy()
+        image.smooth_scaling = self.smooth_scaling
         return image
 
     def get_size(self):
@@ -367,9 +393,11 @@ class BaseImage(object):
         assert isinstance(smooth, bool)
         assert width > 0 and height > 0, 'width and height must be greater than zero'
         w, h = self.get_size()
-        if not smooth:
+        if width == 1 and height == 1:
+            return self
+        if not smooth or self._surface.get_bitsize() < 24:
             self._surface = pygame.transform.scale(self._surface, (int(w * width), int(h * height)))
-        else:
+        else:  # image bitsize less than 24 bits raises ValueError
             self._surface = pygame.transform.smoothscale(self._surface, (int(w * width), int(h * height)))
         return self
 
@@ -462,8 +490,19 @@ class BaseImage(object):
 
         if self._drawing_mode == IMAGE_MODE_FILL:
 
+            # Check if exists the transformed surface
+            if area.width == self._last_transform[0] and area.height == self._last_transform[1] and \
+                    self._last_transform[2] is not None:
+                surf = self._last_transform[2]
+            else:  # Transform scale
+                if self.smooth_scaling and self._surface.get_bitsize() > 8:
+                    surf = pygame.transform.smoothscale(self._surface, (area.width, area.height))
+                else:
+                    surf = pygame.transform.scale(self._surface, (area.width, area.height))
+                self._last_transform = (area.width, area.height, surf)
+
             surface.blit(
-                pygame.transform.scale(self._surface, (area.width, area.height)),
+                surf,
                 (
                     self._drawing_offset[0] + position[0],
                     self._drawing_offset[1] + position[1]
