@@ -58,7 +58,7 @@ class ArrowSelection(Selection):
     :param arrow_vertical_offset: Vertical offset of the arrow
     :type arrow_vertical_offset: int
     :param blink_ms: Milliseconds between each blink, if *0* blinking is disabled
-    :type blink_ms: int
+    :type blink_ms: int, float
     """
 
     def __init__(self, margin_left, margin_right, margin_top, margin_bottom,
