@@ -6,6 +6,9 @@ https://github.com/ppizarror/pygame-menu
 SELECTOR
 Selector class, manage elements and adds entries to menu.
 
+NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
+upgrading to the latest version.
+
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -85,7 +88,7 @@ class Selector(Widget):
     :param onreturn: Callback when pressing return on the selector
     :type onreturn: callable, None
     :param kwargs: Optional keyword arguments
-    :type kwargs: dict
+    :type kwargs: dict, any
     """
 
     def __init__(self,
@@ -181,6 +184,7 @@ class Selector(Widget):
         """
         Set the current value of the widget, selecting the element that matches
         the text if item is a string, or the index of the position of item is an integer.
+        This method raises ``ValueError`` if no element found.
 
         For example, if selector is *[['a',0],['b',1],['a',2]]*:
 
@@ -276,7 +280,7 @@ class Selector(Widget):
             elif self.touchscreen_enabled and event.type == pygame.FINGERUP:
                 window_size = self.get_menu().get_window_size()
                 finger_pos = (event.x * window_size[0], event.y * window_size[1])
-                if rect.collidepoint(finger_pos):
+                if rect.collidepoint(*finger_pos):
                     # Check if mouse collides left or right as percentage, use only X coordinate
                     mousex, _ = finger_pos
                     topleft, _ = rect.topleft
